@@ -15,9 +15,8 @@
 #
 # You should have received a copy of the GNU Lesser General Public License along
 # with CubicWeb.  If not, see <http://www.gnu.org/licenses/>.
-"""utilities for instances migration
+"""utilities for instances migration"""
 
-"""
 __docformat__ = "restructuredtext en"
 
 import sys
