@@ -26,7 +26,7 @@ from logilab.common.deprecation import class_renamed
 from logilab.mtconverter import xml_escape
 
 from cubicweb import role
-from cubicweb.web import json
+from cubicweb.utils import json_dumps
 from cubicweb.view import Component
 from cubicweb.selectors import (
     paginated_rset, one_line_rset, primary_view, match_context_prop,
@@ -146,9 +146,9 @@ class NavigationComponent(Component):
             rql = params.pop('rql', self.cw_rset.printable_rql())
             # latest 'true' used for 'swap' mode
             url = 'javascript: replacePageChunk(%s, %s, %s, %s, true)' % (
-                json.dumps(params.get('divid', 'pageContent')),
-                json.dumps(rql), json.dumps(params.pop('vid', None)),
-                json.dumps(params))
+                json_dumps(params.get('divid', 'pageContent')),
+                json_dumps(rql), json_dumps(params.pop('vid', None)),
+                json_dumps(params))
         else:
             url = self._cw.build_url(path, **params)
         return url
